@@ -1,6 +1,6 @@
 ##
-## $Release: 2.6.5 $
-## copyright(c) 2006-2009 kuwata-lab.com all rights reserved.
+## $Release: 2.6.6 $
+## copyright(c) 2006-2010 kuwata-lab.com all rights reserved.
 ##
 
 
@@ -662,7 +662,7 @@ module Erubis
 
     def _add_text_to_str(str, text)
       return if !text || text.empty?
-      text.gsub!(/['\#\\]/, '\\\\\&')
+      text.gsub!(/[`\#\\]/, '\\\\\&')
       str << text
     end
 
